@@ -1,10 +1,7 @@
-use super::impl_trait::Mode;
-use super::{TypedCodeBlock, TypedExpression};
-use crate::parse_tree::*;
-use crate::span::Span;
-use crate::type_engine::*;
-use crate::{error::*, Ident};
-use sway_types::Property;
+use super::{impl_trait::Mode, TypedCodeBlock, TypedExpression};
+use crate::{error::*, parse_tree::*, type_engine::*, Ident};
+
+use sway_types::{join_spans, span::Span, Property};
 
 mod function;
 mod variable;
@@ -135,11 +132,9 @@ impl TypedDeclaration {
             TraitDeclaration(TypedTraitDeclaration { name, .. }) => name.span().clone(),
             StructDeclaration(TypedStructDeclaration { name, .. }) => name.span().clone(),
             EnumDeclaration(TypedEnumDeclaration { span, .. }) => span.clone(),
-            Reassignment(TypedReassignment { lhs, .. }) => {
-                lhs.iter().fold(lhs[0].span(), |acc, this| {
-                    crate::utils::join_spans(acc, this.span())
-                })
-            }
+            Reassignment(TypedReassignment { lhs, .. }) => lhs
+                .iter()
+                .fold(lhs[0].span(), |acc, this| join_spans(acc, this.span())),
             AbiDeclaration(TypedAbiDeclaration { span, .. }) => span.clone(),
             ImplTrait { span, .. } => span.clone(),
             ErrorRecovery | GenericTypeForFunctionScope { .. } => {
