@@ -1,8 +1,12 @@
 use super::*;
-use crate::build_config::BuildConfig;
-use crate::control_flow_analysis::ControlFlowGraph;
-use crate::semantic_analysis::{ast_node::*, Namespace, TypeCheckArguments};
-use crate::type_engine::{insert_type, IntegerBits};
+
+use crate::{
+    build_config::BuildConfig,
+    control_flow_analysis::ControlFlowGraph,
+    semantic_analysis::{ast_node::*, Namespace, TypeCheckArguments},
+    type_engine::{insert_type, IntegerBits},
+};
+use sway_types::join_spans;
 
 use either::Either;
 use std::cmp::Ordering;
@@ -461,7 +465,7 @@ impl TypedExpression {
                         .get(0)
                         .map(|x| x.span())
                         .unwrap_or_else(|| name.span()),
-                    |acc, arg| crate::utils::join_spans(acc, arg.span()),
+                    |acc, arg| join_spans(acc, arg.span()),
                 );
                 errors.push(CompileError::TooManyArgumentsForFunction {
                     span: arguments_span,
@@ -476,7 +480,7 @@ impl TypedExpression {
                         .get(0)
                         .map(|x| x.span())
                         .unwrap_or_else(|| name.span()),
-                    |acc, arg| crate::utils::join_spans(acc, arg.span()),
+                    |acc, arg| join_spans(acc, arg.span()),
                 );
                 errors.push(CompileError::TooFewArgumentsForFunction {
                     span: arguments_span,
@@ -1796,8 +1800,10 @@ mod tests {
             file_name: Arc::new("test.sw".into()),
             dir_of_code: Arc::new("".into()),
             manifest_path: Arc::new("".into()),
+            use_ir: false,
             print_intermediate_asm: false,
             print_finalized_asm: false,
+            print_ir: false,
         };
         let mut dead_code_graph: ControlFlowGraph = Default::default();
         let mut dependency_graph = HashMap::new();
